@@ -1,5 +1,5 @@
 package PAR;
-$PAR::VERSION = '0.969_01';
+$PAR::VERSION = '0.970_01';
 
 use 5.006;
 use strict;
@@ -13,13 +13,13 @@ PAR - Perl Archive Toolkit
 
 =head1 VERSION
 
-This document describes version 0.97 of PAR, released November 29, 2006.
+This document describes version 0.971 of PAR, released January 10, 2007.
 
 =head1 SYNOPSIS
 
 (If you want to make an executable that contains all module, scripts and
 data files, please consult the L<pp> utility instead. L<pp> used to be
-part of the PAR distribution but is not shipped as part of the L<PAR::Packer>
+part of the PAR distribution but is now shipped as part of the L<PAR::Packer>
 distribution instead.)
 
 Following examples assume a F<foo.par> file in Zip format.
@@ -254,6 +254,20 @@ my $is_insensitive_fs = (
 my $par_temp;
 
 
+# The following section overrides a bug in AutoLoader which results in
+# infinite recursion in case of AUTOLOAD and re-named files.
+# See http://www.nntp.perl.org/group/perl.par/2796 et al.
+require AutoLoader;
+if ($AutoLoader::VERSION <= 5.61) {
+    no strict;
+    no warnings;
+    # If the following doesn't scare you then you scare me.
+    delete $INC{"AutoLoader.pm"};
+    require PAR::AutoLoaderFix;
+    $INC{"AutoLoader.pm"} = $INC{"PAR/AutoLoaderFix.pm"};
+}
+
+
 # called on "use PAR"
 sub import {
     my $class = shift;
@@ -904,6 +918,8 @@ sub _set_progname {
 
 1;
 
+__END__
+
 =head1 SEE ALSO
 
 The PAR homepage at L<http://par.perl.org>.
